==> dglars_1.0.1.tar.gz: dglars/man/breast.Rd <==
\name{breast}
\alias{breast}
\title{
Breast Cancer microarray experiment
}
\description{
This data set details microarray experiment for 52 breast cancer patients. The binary variable \code{status} is used to indicate whether or not the patient has died of breast cancer (\code{status = 0} = did not die of breast cancer, \code{status = 1} = died of breast cancer). The other variables contain the amplification or deletion of the considered genes.

Rather than measuring gene expression, this experiment aims to measure gene amplification or deletion, which refers to the number of copies of a particular DNA sequence within the genome. The aim of the experiment is to find out the key genomic factors involved in agressive and non-agressive forms of breast cancer.

The experiment was conducted by the Dr.\ John Bartlett and Dr.\ Caroline Witton in the Division of Cancer Sciences and Molecular Pathology of the University of Glasgow at the city's Royal Infirmary.
}
\usage{data(breast)}
\source{Dr. John Bartlett and Dr. Caroline Witton, Division of Cancer Sciences and Molecular Pathology, University of Glasgow, Glasgow Royal Infirmary.
}
\references{
Augugliaro L., Mineo A.M. and Wit E.C. (2013)
\emph{dgLARS: a differential geometric approach to sparse generalized linear models}, \emph{Journal of the Royal Statistical Society. Series B.} Vol 75(3), 471-498.
\cr\cr
Wit E.C. and McClure J. (2004) "Statistics for Microarrays: Design, Analysis and Inference" Chichester: Wiley.
}
\keyword{datasets}

==> dglars_2.1.7.tar.gz: dglars/man/breast.Rd <==
\name{breast}
\docType{data}
\alias{breast}
\title{
Breast Cancer microarray experiment
}
\description{
This data set details microarray experiment for 52 breast cancer patients. The binary variable \code{status} is used to indicate whether or not the patient has died of breast cancer (\code{status = 0} = did not die of breast cancer, \code{status = 1} = died of breast cancer). The other variables contain the amplification or deletion of the considered genes.

Rather than measuring gene expression, this experiment aims to measure gene amplification or deletion, which refers to the number of copies of a particular DNA sequence within the genome. The aim of the experiment is to find out the key genomic factors involved in agressive and non-agressive forms of breast cancer.

The experiment was conducted by the Dr.\ John Bartlett and Dr.\ Caroline Witton in the Division of Cancer Sciences and Molecular Pathology of the University of Glasgow at the city's Royal Infirmary.
}
\usage{data(breast)}
\source{Dr. John Bartlett and Dr. Caroline Witton, Division of Cancer Sciences and Molecular Pathology, University of Glasgow, Glasgow Royal Infirmary.
}
\references{
Augugliaro L., Mineo A.M. and Wit E.C. (2013) <doi:10.1111/rssb.12000>
\emph{dgLARS: a differential geometric approach to sparse generalized linear models}, \emph{Journal of the Royal Statistical Society. Series B.}, Vol 75(3), 471-498.

Wit E.C. and McClure J. (2004, ISBN:978-0-470-84993-4)
"Statistics for Microarrays: Design, Analysis and Inference"
Chichester: Wiley.
}
\keyword{datasets}
